# IRON-BARK: Inter Process Communication
A lightweight library allowing the communication between several programs through SharedMemory.

### Features
* Implementation of a functional version
* Creation of a communication module by JSON file

### Ongoing
* Overloading dict methods to call Sender and Listener

### Future improvement
* Adding remote communication

### More
[![PyPI version](https://badge.fury.io/py/IRONbark.svg)](https://badge.fury.io/py/IRONbark)
![Python package](https://github.com/Zentetsu/IRON/workflows/Python%20package/badge.svg?branch=master)
![Upload Python Package](https://github.com/Zentetsu/IRONbark/workflows/Upload%20Python%20Package/badge.svg)
[![Python](https://shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-380/)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
